slepc-3.18.0 2022-10-01
Report Typos and Errors

# BVNormColumn

Computes the vector norm of a selected column.

### Synopsis

    #include "slepcbv.h"
    PetscErrorCode BVNormColumn(BV bv,PetscInt j,NormType type,PetscReal *val)

Collective on bv

### Input Parameters

| bv | - basis vectors
| j | - column number to be used
| type | - the norm type

### Output Parameter

| val | - the norm

### Notes

The norm of V[j] is computed (NORM_1, NORM_2, or NORM_INFINITY). If a non-standard inner product has been specified with BVSetMatrix(), then the returned value is sqrt(V[j]'*B*V[j]), where B is the inner product matrix (argument 'type' is ignored).

### See Also

BVNorm(), BVNormVec(), BVNormalize(), BVSetActiveColumns(), BVSetMatrix()

### Level

intermediate

### Location

src/sys/classes/bv/interface/bvglobal.c
Index of all BV routines
Table of Contents for all manual pages
Index of all manual pages